@@ -20,13 +20,18 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 import warnings
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.cloud.bigquery_reservation_v1.services.reservation_service import pagers
 from google.cloud.bigquery_reservation_v1.types import reservation
 from google.cloud.bigquery_reservation_v1.types import reservation as gcbr_reservation
@@ -200,19 +205,19 @@ class ReservationServiceAsyncClient:
 
     async def create_reservation(
         self,
-        request: gcbr_reservation.CreateReservationRequest = None,
+        request: Union[gcbr_reservation.CreateReservationRequest, dict] = None,
         *,
         parent: str = None,
         reservation: gcbr_reservation.Reservation = None,
         reservation_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcbr_reservation.Reservation:
         r"""Creates a new reservation resource.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.CreateReservationRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.CreateReservationRequest, dict]):
                 The request object. The request for
                 [ReservationService.CreateReservation][google.cloud.bigquery.reservation.v1.ReservationService.CreateReservation].
             parent (:class:`str`):
@@ -293,10 +298,10 @@ class ReservationServiceAsyncClient:
 
     async def list_reservations(
         self,
-        request: reservation.ListReservationsRequest = None,
+        request: Union[reservation.ListReservationsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListReservationsAsyncPager:
@@ -304,7 +309,7 @@ class ReservationServiceAsyncClient:
         specified location.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.ListReservationsRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.ListReservationsRequest, dict]):
                 The request object. The request for
                 [ReservationService.ListReservations][google.cloud.bigquery.reservation.v1.ReservationService.ListReservations].
             parent (:class:`str`):
@@ -358,9 +363,9 @@ class ReservationServiceAsyncClient:
                     core_exceptions.DeadlineExceeded,
                     core_exceptions.ServiceUnavailable,
                 ),
-                deadline=60.0,
+                deadline=300.0,
             ),
-            default_timeout=60.0,
+            default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
@@ -384,17 +389,17 @@ class ReservationServiceAsyncClient:
 
     async def get_reservation(
         self,
-        request: reservation.GetReservationRequest = None,
+        request: Union[reservation.GetReservationRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> reservation.Reservation:
         r"""Returns information about the reservation.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.GetReservationRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.GetReservationRequest, dict]):
                 The request object. The request for
                 [ReservationService.GetReservation][google.cloud.bigquery.reservation.v1.ReservationService.GetReservation].
             name (:class:`str`):
@@ -446,9 +451,9 @@ class ReservationServiceAsyncClient:
                     core_exceptions.DeadlineExceeded,
                     core_exceptions.ServiceUnavailable,
                 ),
-                deadline=60.0,
+                deadline=300.0,
             ),
-            default_timeout=60.0,
+            default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
@@ -466,10 +471,10 @@ class ReservationServiceAsyncClient:
 
     async def delete_reservation(
         self,
-        request: reservation.DeleteReservationRequest = None,
+        request: Union[reservation.DeleteReservationRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -478,7 +483,7 @@ class ReservationServiceAsyncClient:
         assignments.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.DeleteReservationRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.DeleteReservationRequest, dict]):
                 The request object. The request for
                 [ReservationService.DeleteReservation][google.cloud.bigquery.reservation.v1.ReservationService.DeleteReservation].
             name (:class:`str`):
@@ -524,9 +529,9 @@ class ReservationServiceAsyncClient:
                     core_exceptions.DeadlineExceeded,
                     core_exceptions.ServiceUnavailable,
                 ),
-                deadline=60.0,
+                deadline=300.0,
             ),
-            default_timeout=60.0,
+            default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
@@ -543,18 +548,18 @@ class ReservationServiceAsyncClient:
 
     async def update_reservation(
         self,
-        request: gcbr_reservation.UpdateReservationRequest = None,
+        request: Union[gcbr_reservation.UpdateReservationRequest, dict] = None,
         *,
         reservation: gcbr_reservation.Reservation = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcbr_reservation.Reservation:
         r"""Updates an existing reservation resource.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.UpdateReservationRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.UpdateReservationRequest, dict]):
                 The request object. The request for
                 [ReservationService.UpdateReservation][google.cloud.bigquery.reservation.v1.ReservationService.UpdateReservation].
             reservation (:class:`google.cloud.bigquery_reservation_v1.types.Reservation`):
@@ -624,18 +629,18 @@ class ReservationServiceAsyncClient:
 
     async def create_capacity_commitment(
         self,
-        request: reservation.CreateCapacityCommitmentRequest = None,
+        request: Union[reservation.CreateCapacityCommitmentRequest, dict] = None,
         *,
         parent: str = None,
         capacity_commitment: reservation.CapacityCommitment = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> reservation.CapacityCommitment:
         r"""Creates a new capacity commitment resource.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.CreateCapacityCommitmentRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.CreateCapacityCommitmentRequest, dict]):
                 The request object. The request for
                 [ReservationService.CreateCapacityCommitment][google.cloud.bigquery.reservation.v1.ReservationService.CreateCapacityCommitment].
             parent (:class:`str`):
@@ -717,10 +722,10 @@ class ReservationServiceAsyncClient:
 
     async def list_capacity_commitments(
         self,
-        request: reservation.ListCapacityCommitmentsRequest = None,
+        request: Union[reservation.ListCapacityCommitmentsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListCapacityCommitmentsAsyncPager:
@@ -728,7 +733,7 @@ class ReservationServiceAsyncClient:
         project.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.ListCapacityCommitmentsRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.ListCapacityCommitmentsRequest, dict]):
                 The request object. The request for
                 [ReservationService.ListCapacityCommitments][google.cloud.bigquery.reservation.v1.ReservationService.ListCapacityCommitments].
             parent (:class:`str`):
@@ -782,9 +787,9 @@ class ReservationServiceAsyncClient:
                     core_exceptions.DeadlineExceeded,
                     core_exceptions.ServiceUnavailable,
                 ),
-                deadline=60.0,
+                deadline=300.0,
             ),
-            default_timeout=60.0,
+            default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
@@ -808,17 +813,17 @@ class ReservationServiceAsyncClient:
 
     async def get_capacity_commitment(
         self,
-        request: reservation.GetCapacityCommitmentRequest = None,
+        request: Union[reservation.GetCapacityCommitmentRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> reservation.CapacityCommitment:
         r"""Returns information about the capacity commitment.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.GetCapacityCommitmentRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.GetCapacityCommitmentRequest, dict]):
                 The request object. The request for
                 [ReservationService.GetCapacityCommitment][google.cloud.bigquery.reservation.v1.ReservationService.GetCapacityCommitment].
             name (:class:`str`):
@@ -882,9 +887,9 @@ class ReservationServiceAsyncClient:
                     core_exceptions.DeadlineExceeded,
                     core_exceptions.ServiceUnavailable,
                 ),
-                deadline=60.0,
+                deadline=300.0,
             ),
-            default_timeout=60.0,
+            default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
@@ -902,10 +907,10 @@ class ReservationServiceAsyncClient:
 
     async def delete_capacity_commitment(
         self,
-        request: reservation.DeleteCapacityCommitmentRequest = None,
+        request: Union[reservation.DeleteCapacityCommitmentRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -914,7 +919,7 @@ class ReservationServiceAsyncClient:
         error code ``google.rpc.Code.FAILED_PRECONDITION``.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.DeleteCapacityCommitmentRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.DeleteCapacityCommitmentRequest, dict]):
                 The request object. The request for
                 [ReservationService.DeleteCapacityCommitment][google.cloud.bigquery.reservation.v1.ReservationService.DeleteCapacityCommitment].
             name (:class:`str`):
@@ -960,9 +965,9 @@ class ReservationServiceAsyncClient:
                     core_exceptions.DeadlineExceeded,
                     core_exceptions.ServiceUnavailable,
                 ),
-                deadline=60.0,
+                deadline=300.0,
             ),
-            default_timeout=60.0,
+            default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
@@ -979,11 +984,11 @@ class ReservationServiceAsyncClient:
 
     async def update_capacity_commitment(
         self,
-        request: reservation.UpdateCapacityCommitmentRequest = None,
+        request: Union[reservation.UpdateCapacityCommitmentRequest, dict] = None,
         *,
         capacity_commitment: reservation.CapacityCommitment = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> reservation.CapacityCommitment:
@@ -997,7 +1002,7 @@ class ReservationServiceAsyncClient:
         ``google.rpc.Code.FAILED_PRECONDITION``.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.UpdateCapacityCommitmentRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.UpdateCapacityCommitmentRequest, dict]):
                 The request object. The request for
                 [ReservationService.UpdateCapacityCommitment][google.cloud.bigquery.reservation.v1.ReservationService.UpdateCapacityCommitment].
             capacity_commitment (:class:`google.cloud.bigquery_reservation_v1.types.CapacityCommitment`):
@@ -1081,11 +1086,11 @@ class ReservationServiceAsyncClient:
 
     async def split_capacity_commitment(
         self,
-        request: reservation.SplitCapacityCommitmentRequest = None,
+        request: Union[reservation.SplitCapacityCommitmentRequest, dict] = None,
         *,
         name: str = None,
         slot_count: int = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> reservation.SplitCapacityCommitmentResponse:
@@ -1100,7 +1105,7 @@ class ReservationServiceAsyncClient:
         ``FLEX`` and then delete it.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.SplitCapacityCommitmentRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.SplitCapacityCommitmentRequest, dict]):
                 The request object. The request for
                 [ReservationService.SplitCapacityCommitment][google.cloud.bigquery.reservation.v1.ReservationService.SplitCapacityCommitment].
             name (:class:`str`):
@@ -1170,11 +1175,11 @@ class ReservationServiceAsyncClient:
 
     async def merge_capacity_commitments(
         self,
-        request: reservation.MergeCapacityCommitmentsRequest = None,
+        request: Union[reservation.MergeCapacityCommitmentsRequest, dict] = None,
         *,
         parent: str = None,
         capacity_commitment_ids: Sequence[str] = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> reservation.CapacityCommitment:
@@ -1190,7 +1195,7 @@ class ReservationServiceAsyncClient:
         ``google.rpc.Code.FAILED_PRECONDITION``.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.MergeCapacityCommitmentsRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.MergeCapacityCommitmentsRequest, dict]):
                 The request object. The request for
                 [ReservationService.MergeCapacityCommitments][google.cloud.bigquery.reservation.v1.ReservationService.MergeCapacityCommitments].
             parent (:class:`str`):
@@ -1277,11 +1282,11 @@ class ReservationServiceAsyncClient:
 
     async def create_assignment(
         self,
-        request: reservation.CreateAssignmentRequest = None,
+        request: Union[reservation.CreateAssignmentRequest, dict] = None,
         *,
         parent: str = None,
         assignment: reservation.Assignment = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> reservation.Assignment:
@@ -1325,7 +1330,7 @@ class ReservationServiceAsyncClient:
         the assignment does not match location of the reservation.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.CreateAssignmentRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.CreateAssignmentRequest, dict]):
                 The request object. The request for
                 [ReservationService.CreateAssignment][google.cloud.bigquery.reservation.v1.ReservationService.CreateAssignment].
                 Note: "bigquery.reservationAssignments.create"
@@ -1397,10 +1402,10 @@ class ReservationServiceAsyncClient:
 
     async def list_assignments(
         self,
-        request: reservation.ListAssignmentsRequest = None,
+        request: Union[reservation.ListAssignmentsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAssignmentsAsyncPager:
@@ -1428,7 +1433,7 @@ class ReservationServiceAsyncClient:
         **Note** "-" cannot be used for projects nor locations.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.ListAssignmentsRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.ListAssignmentsRequest, dict]):
                 The request object. The request for
                 [ReservationService.ListAssignments][google.cloud.bigquery.reservation.v1.ReservationService.ListAssignments].
             parent (:class:`str`):
@@ -1487,9 +1492,9 @@ class ReservationServiceAsyncClient:
                     core_exceptions.DeadlineExceeded,
                     core_exceptions.ServiceUnavailable,
                 ),
-                deadline=60.0,
+                deadline=300.0,
             ),
-            default_timeout=60.0,
+            default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
@@ -1513,10 +1518,10 @@ class ReservationServiceAsyncClient:
 
     async def delete_assignment(
         self,
-        request: reservation.DeleteAssignmentRequest = None,
+        request: Union[reservation.DeleteAssignmentRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1538,7 +1543,7 @@ class ReservationServiceAsyncClient:
         ``project2`` will switch to use on-demand mode.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.DeleteAssignmentRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.DeleteAssignmentRequest, dict]):
                 The request object. The request for
                 [ReservationService.DeleteAssignment][google.cloud.bigquery.reservation.v1.ReservationService.DeleteAssignment].
                 Note: "bigquery.reservationAssignments.delete"
@@ -1585,9 +1590,9 @@ class ReservationServiceAsyncClient:
                     core_exceptions.DeadlineExceeded,
                     core_exceptions.ServiceUnavailable,
                 ),
-                deadline=60.0,
+                deadline=300.0,
             ),
-            default_timeout=60.0,
+            default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
@@ -1604,11 +1609,11 @@ class ReservationServiceAsyncClient:
 
     async def search_assignments(
         self,
-        request: reservation.SearchAssignmentsRequest = None,
+        request: Union[reservation.SearchAssignmentsRequest, dict] = None,
         *,
         parent: str = None,
         query: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.SearchAssignmentsAsyncPager:
@@ -1639,7 +1644,7 @@ class ReservationServiceAsyncClient:
         **Note** "-" cannot be used for projects nor locations.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.SearchAssignmentsRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.SearchAssignmentsRequest, dict]):
                 The request object. The request for
                 [ReservationService.SearchAssignments][google.cloud.bigquery.reservation.v1.ReservationService.SearchAssignments].
                 Note: "bigquery.reservationAssignments.search"
@@ -1661,7 +1666,6 @@ class ReservationServiceAsyncClient:
                 -  ``assignee=folders/123``
                 -  ``assignee=organizations/456``
 
-
                 This corresponds to the ``query`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1716,9 +1720,9 @@ class ReservationServiceAsyncClient:
                     core_exceptions.DeadlineExceeded,
                     core_exceptions.ServiceUnavailable,
                 ),
-                deadline=60.0,
+                deadline=300.0,
             ),
-            default_timeout=60.0,
+            default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
@@ -1742,11 +1746,11 @@ class ReservationServiceAsyncClient:
 
     async def search_all_assignments(
         self,
-        request: reservation.SearchAllAssignmentsRequest = None,
+        request: Union[reservation.SearchAllAssignmentsRequest, dict] = None,
         *,
         parent: str = None,
         query: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.SearchAllAssignmentsAsyncPager:
@@ -1775,7 +1779,7 @@ class ReservationServiceAsyncClient:
            ``projects/*/locations/*reservations/*``.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.SearchAllAssignmentsRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.SearchAllAssignmentsRequest, dict]):
                 The request object. The request for
                 [ReservationService.SearchAllAssignments][google.cloud.bigquery.reservation.v1.ReservationService.SearchAllAssignments].
                 Note: "bigquery.reservationAssignments.search"
@@ -1797,7 +1801,6 @@ class ReservationServiceAsyncClient:
                 -  ``assignee=folders/123``
                 -  ``assignee=organizations/456``
 
-
                 This corresponds to the ``query`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1863,11 +1866,11 @@ class ReservationServiceAsyncClient:
 
     async def move_assignment(
         self,
-        request: reservation.MoveAssignmentRequest = None,
+        request: Union[reservation.MoveAssignmentRequest, dict] = None,
         *,
         name: str = None,
         destination_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> reservation.Assignment:
@@ -1878,7 +1881,7 @@ class ReservationServiceAsyncClient:
         reservation.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.MoveAssignmentRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.MoveAssignmentRequest, dict]):
                 The request object. The request for
                 [ReservationService.MoveAssignment][google.cloud.bigquery.reservation.v1.ReservationService.MoveAssignment].
                 **Note**: "bigquery.reservationAssignments.create"
@@ -1955,17 +1958,17 @@ class ReservationServiceAsyncClient:
 
     async def get_bi_reservation(
         self,
-        request: reservation.GetBiReservationRequest = None,
+        request: Union[reservation.GetBiReservationRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> reservation.BiReservation:
         r"""Retrieves a BI reservation.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.GetBiReservationRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.GetBiReservationRequest, dict]):
                 The request object. A request to get a singleton BI
                 reservation.
             name (:class:`str`):
@@ -2015,9 +2018,9 @@ class ReservationServiceAsyncClient:
                     core_exceptions.DeadlineExceeded,
                     core_exceptions.ServiceUnavailable,
                 ),
-                deadline=60.0,
+                deadline=300.0,
             ),
-            default_timeout=60.0,
+            default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
         )
 
@@ -2035,11 +2038,11 @@ class ReservationServiceAsyncClient:
 
     async def update_bi_reservation(
         self,
-        request: reservation.UpdateBiReservationRequest = None,
+        request: Union[reservation.UpdateBiReservationRequest, dict] = None,
         *,
         bi_reservation: reservation.BiReservation = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> reservation.BiReservation:
@@ -2053,7 +2056,7 @@ class ReservationServiceAsyncClient:
         must be set to 0.
 
         Args:
-            request (:class:`google.cloud.bigquery_reservation_v1.types.UpdateBiReservationRequest`):
+            request (Union[google.cloud.bigquery_reservation_v1.types.UpdateBiReservationRequest, dict]):
                 The request object. A request to update a BI
                 reservation.
             bi_reservation (:class:`google.cloud.bigquery_reservation_v1.types.BiReservation`):
